@@ -1,12 +1,13 @@
 (**************************************************************************)
 (*    Lablgtk - Examples                                                  *)
 (*                                                                        *)
-(*    This code is in the public domain.                                  *)
-(*    You may freely copy parts of it in your application.                *)
+(*    There is no specific licensing policy, but you may freely           *)
+(*    take inspiration from the code, and copy parts of it in your        *)
+(*    application.                                                        *)
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
+(* $Id: image.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
 
 open GMain
 open Gdk
@@ -14,21 +15,19 @@ open Gdk
 (* load image *)
 let load_image file =
   print_endline "Load as string";
-  let buf = Bytes.create (256*256*3) in
+  let buf = String.create (256*256*3) in
   let ic = open_in_bin file in
   really_input ic buf 0 (256*256*3);
   close_in ic;
   buf
 
-let (.![]) = Bytes.get
-
 let rgb_at buf x y =
   let offset = (y * 256 + x) * 3 in
-  (int_of_char (buf.![offset  ]),
-   int_of_char (buf.![offset+1]),
-   int_of_char (buf.![offset+2]))
+  (int_of_char buf.[offset  ],
+   int_of_char buf.[offset+1],
+   int_of_char buf.[offset+2])
 
-let create_region = Gpointer.region_of_bytes
+let create_region = Gpointer.region_of_string
 
 (* alternate approach: map the file *)
 (* Requires bigarray.cma, but needed for Rgb.draw_image *)
