@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
+(* $Id: gTree.mli 1523 2010-07-25 12:42:26Z garrigue $ *)
 
 open Gobject
 open Gtk
@@ -371,21 +371,6 @@ class view_signals : [> tree_view] obj ->
       callback:(tree_iter -> tree_path -> bool) -> GtkSignal.id
     method toggle_cursor_row : callback:(unit -> bool) -> GtkSignal.id
     method unselect_all : callback:(unit -> bool) -> GtkSignal.id
-    method notify_enable_search : callback:(bool -> unit) -> GtkSignal.id
-    method notify_enable_tree_lines : callback:(bool -> unit) -> GtkSignal.id
-    method notify_enable_grid_lines :
-      callback:(GtkEnums.tree_view_grid_lines -> unit) -> GtkSignal.id
-    method notify_fixed_height_mode : callback:(bool -> unit) -> GtkSignal.id
-    method notify_hadjustment : callback:(GData.adjustment -> unit) -> GtkSignal.id
-    method notify_headers_visible : callback:(bool -> unit) -> GtkSignal.id
-    method notify_hover_expand : callback:(bool -> unit) -> GtkSignal.id
-    method notify_hover_selection : callback:(bool -> unit) -> GtkSignal.id
-    method notify_reorderable : callback:(bool -> unit) -> GtkSignal.id
-    method notify_rules_hint : callback:(bool -> unit) -> GtkSignal.id
-    method notify_search_column : callback:(int -> unit) -> GtkSignal.id
-    method notify_tooltip_column : callback:(int -> unit) -> GtkSignal.id
-    method notify_vadjustment :
-      callback:(GData.adjustment -> unit) -> GtkSignal.id
   end
 
 (** A widget for displaying both trees and lists
@@ -452,16 +437,8 @@ class view : tree_view obj ->
     method set_hover_expand : bool -> unit (** @since GTK 2.6 *)
     method hover_selection : bool (** @since GTK 2.6 *)
     method set_hover_selection : bool -> unit (** @since GTK 2.6 *)
-    method set_row_separator_func :
-        (model -> tree_iter -> bool) option -> unit (** @since GTK 2.6 *)
-    method enable_grid_lines : GtkEnums.tree_view_grid_lines
-        (** @since GTK 2.10 *)
-    method enable_tree_lines : bool (** @since GTK 2.10 *)
-    method set_enable_grid_lines : GtkEnums.tree_view_grid_lines -> unit
-        (** @since GTK 2.10 *)
-    method set_enable_tree_lines : bool -> unit
-        (** @since GTK 2.10 *)
-    end
+    method set_row_separator_func : (model -> tree_iter -> bool) option -> unit (** @since GTK 2.6 *)
+  end
 
 (** @gtkdoc gtk GtkTreeView *)
 val view :
@@ -690,14 +667,6 @@ class icon_view_signals : [> Gtk.icon_view] Gtk.obj ->
     inherit GContainer.container_signals
     method item_activated : callback:(Gtk.tree_path -> unit) -> GtkSignal.id
     method selection_changed : callback:(unit -> unit) -> GtkSignal.id
-    method notify_column_spacing : callback:(int -> unit) -> GtkSignal.id
-    method notify_columns : callback:(int -> unit) -> GtkSignal.id
-    method notify_item_width : callback:(int -> unit) -> GtkSignal.id
-    method notify_margin : callback:(int -> unit) -> GtkSignal.id
-    method notify_orientation : callback:(GtkEnums.orientation -> unit) -> GtkSignal.id
-    method notify_row_spacing : callback:(int -> unit) -> GtkSignal.id
-    method notify_selection_mode : callback:(GtkEnums.selection_mode -> unit) -> GtkSignal.id
-    method notify_spacing : callback:(int -> unit) -> GtkSignal.id
   end
 
 (** A widget which displays a list of icons in a grid
@@ -735,7 +704,7 @@ class icon_view :
     method spacing : int
     method set_spacing : int -> unit
 
-    method get_path_at_pos : int -> int -> Gtk.tree_path option
+    method get_path_at_pos : int -> int -> Gtk.tree_path
     method selected_foreach : (Gtk.tree_path -> unit) -> unit
     method get_selected_items : Gtk.tree_path list
     method path_is_selected : Gtk.tree_path -> bool
