@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gWindow.ml 1402 2008-03-25 08:55:03Z garrigue $ *)
+(* $Id: gWindow.ml 1515 2010-06-08 08:50:23Z garrigue $ *)
 
 open Gaux
 open Gtk
@@ -46,7 +46,6 @@ class window_skel obj = object (self)
   method activate_focus () = Window.activate_focus obj
   method activate_default () = Window.activate_default obj
   method add_accel_group = Window.add_accel_group obj
-  method set_modal = set obj P.modal
   method set_default_size ~width ~height =
     set obj P.default_width width;
     set obj P.default_height height
@@ -172,7 +171,7 @@ class ['a] dialog_ext obj = object (self)
 end
 
 class ['a] dialog obj = object (self)
-  inherit ['a] dialog_ext obj
+  inherit ['a] dialog_ext (obj :> Gtk.dialog obj)
   method connect : 'a dialog_signals = new dialog_signals obj (self#decode)
 end
 
@@ -194,7 +193,7 @@ let dialog ?(no_separator=false) =
 type any_response = [GtkEnums.response | `OTHER of int]
 
 class dialog_any obj = object (self)
-  inherit [any_response] dialog_base obj
+  inherit [any_response] dialog_base (obj :> Gtk.dialog obj)
   method private encode = function
       `OTHER n -> n
     | #GtkEnums.response as v -> Dialog.std_response v
@@ -244,11 +243,19 @@ let message_dialog ?(message="") ?(use_markup=false) ~message_type ~buttons =
 
 (** AboutDialog *)
 
+let namep =
+  if GtkMain.Main.version >= (2,12,0)
+  then GtkBaseProps.AboutDialog.P.program_name
+  else GtkBaseProps.Widget.P.name
+
 class about_dialog obj =
   object (self)
     inherit [Buttons.about] dialog_skel obj
-    inherit about_dialog_props
-    method connect : Buttons.about dialog_signals = new dialog_signals obj self#decode
+    inherit about_dialog_props as props
+    method name = Gobject.get namep obj
+    method set_name = Gobject.set namep obj
+    method connect : Buttons.about dialog_signals =
+      new dialog_signals obj self#decode
     method set_artists = AboutDialog.set_artists obj
     method artists = AboutDialog.get_artists obj
     method set_authors = AboutDialog.set_authors obj
@@ -259,8 +266,9 @@ class about_dialog obj =
       tbl <- [ rcancel, `CANCEL ; rclose, `CLOSE ] @ tbl
   end
 
-let about_dialog ?authors =
-  AboutDialog.make_params [] ~cont:(fun pl ->
+let about_dialog ?name ?authors =
+  let pl = Gobject.Property.may_cons namep name [] in
+  AboutDialog.make_params pl ~cont:(fun pl ->
     make_dialog pl ~create:(fun pl ->
       let d = AboutDialog.create () in
       Gobject.set_params d pl ;
