@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gobject.c 1390 2007-11-28 05:26:18Z garrigue $ */
+/* $Id: ml_gobject.c 1524 2010-08-16 02:50:14Z garrigue $ */
 #include <stdio.h>
 #include <glib.h>
 #include <glib-object.h>
@@ -39,13 +39,21 @@
 
 /* gobject.h */
 
-static gboolean ml_g_object_unref0 (gpointer p)
-{ g_object_unref((GObject*)p); return 0; }
+static GQueue objects_to_unref; /* initialized to zeroes (empty queue) */
+
+CAMLprim value ml_g_object_do_unref (value unit)
+{
+  while (! g_queue_is_empty (&objects_to_unref))
+    {
+      gpointer d = g_queue_pop_tail (&objects_to_unref);
+      g_object_unref (G_OBJECT (d));
+    }
+  return Val_unit;
+}
 
 CAMLexport void ml_g_object_unref_later (GObject *p)
 {
-    g_timeout_add_full(G_PRIORITY_HIGH_IDLE, 0, ml_g_object_unref0,
-                       (gpointer)(p), NULL);
+  g_queue_push_head (&objects_to_unref, p);
 }
 
 
@@ -70,11 +78,25 @@ static GType my_g_object_get_property_type(GObject *obj, const char *prop)
 {
     GParamSpec *pspec =
         g_object_class_find_property (G_OBJECT_GET_CLASS(obj), prop);
-    if (pspec == NULL) raise_not_found();
+    if (pspec == NULL) { 
+      g_warning("LablGtk tried to access the unsupported property %s",prop); 
+      caml_invalid_argument(prop);
+      }
     return pspec->value_type;
 }
 ML_2 (my_g_object_get_property_type, GObject_val, String_val, Val_GType)
 
+static GType internal_g_object_get_property_type(GObject *obj, const char *prop)
+{
+    GParamSpec *pspec =
+        g_object_class_find_property (G_OBJECT_GET_CLASS(obj), prop);
+    if (pspec == NULL) { 
+      g_warning("LablGtk tried to access the unsupported property %s",prop);
+      return G_TYPE_INVALID;
+      }
+    return pspec->value_type;
+}
+
 
 /* gtype.h */
 
@@ -267,7 +289,7 @@ CAMLprim value Val_gboxed_new(GType t, gpointer p)
 
 #define DATA  (val->data[0])
 
-static value g_value_get_variant (GValue *val)
+static value g_value_get_mlvariant (GValue *val)
 {
     CAMLparam0();
     CAMLlocal1(tmp);
@@ -353,9 +375,9 @@ static value g_value_get_variant (GValue *val)
     CAMLreturn(ret);
 }
 
-ML_1 (g_value_get_variant, GValue_val, ID)
+ML_1 (g_value_get_mlvariant, GValue_val, ID)
 
-static void g_value_set_variant (GValue *val, value arg)
+static void g_value_set_mlvariant (GValue *val, value arg)
 {
     value tag = Field(arg,0);
     value data = Field(arg,1);
@@ -439,7 +461,7 @@ static void g_value_set_variant (GValue *val, value arg)
     return;
 }
 
-ML_2 (g_value_set_variant, GValue_val, ID, Unit)
+ML_2 (g_value_set_mlvariant, GValue_val, ID, Unit)
 
 CAMLprim value ml_g_value_get_nativeint(value arg) {
     GValue *val = GValue_val(arg);
@@ -510,7 +532,7 @@ CAMLprim value ml_g_object_new (value type, value params)
         pspec = g_object_class_find_property (class, param->name);
         if (!pspec) failwith ("Gobject.create");
         g_value_init (&param->value, pspec->value_type);
-        g_value_set_variant (&param->value, Field(Field(cell,0),1));
+        g_value_set_mlvariant (&param->value, Field(Field(cell,0),1));
         param++;
       }
     }
@@ -528,12 +550,13 @@ CAMLprim value ml_g_object_new (value type, value params)
 CAMLprim value ml_g_object_get_property_dyn (value vobj, value prop)
 {
   GObject *obj = GObject_val(vobj);
-  GType tp = my_g_object_get_property_type(obj, String_val(prop));
+  GType tp = internal_g_object_get_property_type(obj, String_val(prop));
   GValue val = {0};
   value ret;
+  if (tp == G_TYPE_INVALID) caml_invalid_argument(String_val(prop));
   g_value_init (&val, tp);
   g_object_get_property (obj, String_val(prop), &val);
-  ret = g_value_get_variant (&val);
+  ret = g_value_get_mlvariant (&val);
   g_value_unset (&val);
   return ret;
 }
@@ -541,10 +564,11 @@ CAMLprim value ml_g_object_get_property_dyn (value vobj, value prop)
 CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
 {
   GObject *obj = GObject_val(vobj);
-  GType tp = my_g_object_get_property_type(obj, String_val(prop));
+  GType tp = internal_g_object_get_property_type(obj, String_val(prop));
   GValue val = {0};
+  if (tp == G_TYPE_INVALID) return Val_unit; /* Silently ignore this error */
   g_value_init (&val, tp);
-  g_value_set_variant (&val, arg);
+  g_value_set_mlvariant (&val, arg);
   g_object_set_property (obj, String_val(prop), &val);
   g_value_unset (&val);
   return Val_unit;
@@ -587,7 +611,7 @@ CAMLprim value ml_g_signal_emit_by_name (value obj, value sig, value params)
     for (i = 0; i < query.n_params; i++) {
         g_value_init (&iparams[i+1],
                       query.param_types[i] & ~G_SIGNAL_TYPE_STATIC_SCOPE);
-        g_value_set_variant (&iparams[i+1], Field(params,i));
+        g_value_set_mlvariant (&iparams[i+1], Field(params,i));
     }
     g_signal_emitv (iparams, signal_id, detail, (ret ? GValue_val(ret) : 0));
     for (i = 0; i < query.n_params + 1; i++)
