@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_gtktext.c 1499 2010-04-08 08:00:42Z garrigue $ */
 /* Author: Benjamin Monate */
 
 #include <stdio.h>
@@ -105,17 +105,6 @@ CAMLprim value ml_gtk_text_iter_copy (value it) {
   return Val_GtkTextIter(GtkTextIter_val(it));
 }
 
-/* Defined from Gtk 3.2 onwards, and explicitely written for bindings */
-CAMLprim value ml_gtk_text_iter_assign (value it1, value it2) {
-  CAMLparam2(it1, it2);
-  GtkTextIter* iter = GtkTextIter_val(it1);
-  GtkTextIter* other = GtkTextIter_val(it2);
-  g_return_val_if_fail (iter != NULL, Val_unit);
-  g_return_val_if_fail (other != NULL, Val_unit);
-  *iter = *other;
-  CAMLreturn(Val_unit);
-}
-
 /* gtktextmark */
 
 ML_2(gtk_text_mark_set_visible, GtkTextMark_val, Bool_val, Unit)
@@ -596,7 +585,7 @@ CAMLprim value ml_gtk_text_view_buffer_to_window_coords (value tv,
   int bx,by = 0;
 
   gtk_text_view_buffer_to_window_coords(GtkTextView_val(tv),
-					Text_window_type_val(tt),
+					(GtkTextWindowType)tt,
 					Int_val(x),Int_val(y),
 					&bx,&by);
 
